<?php

/**
 * @file
 * Contains \Drupal\entity_pilot\Entity\ArrivalInterface.
 */

namespace Drupal\entity_pilot;

/**
 * Provides an interface defining an Incoming Entity Pilot flight entity.
 */
interface ArrivalInterface extends FlightInterface {

  /**
   * Gets the json-encoded normalized entities.
   *
   * @return string
   *   Contents of the flight.
   */
  public function getContents();

  /**
   * Returns passengers in the arrival or all passengers.
   *
   * @param string $uuid
   *   (optional) Passenger UUID to return, if NULL returns all records.
   *   Defaults to NULL.
   *
   * @return array
   *   If a UUID is passed, individual normalized passenger, else array of
   *   normalized passengers.
   * @throws \InvalidArgumentException
   *   When the passed ID does not exist in the flight.
   */
  public function getPassengers($uuid = NULL);

  /**
   * Sets contents on the flight.
   *
   * @param array $contents
   *   Array of hal+json encoded entities.
   *
   * @return self
   *   The instance the method was called on.
   */
  public function setContents($contents);

  /**
   * Gets the approved passengers.
   *
   * @return array
   *   Array of approved passenger UUIDs.
   */
  public function getApproved();

}
