<?php

/**
 * @file
 * Contains \Drupal\entity_pilot\Encryption\EncrypterInterface.
 */

namespace Drupal\entity_pilot\Encryption;

/**
 * Defines an interface for encrypting and decrypting.
 */
interface EncrypterInterface {

  /**
   * Encrypts data using the given secret.
   *
   * @param string $secret
   *   Secret key - no need to base64encode - will be encoded by the method.
   * @param string $data
   *   Data to encrypt.
   *
   * @return string
   *   Encrypted content.
   */
  public static function encrypt($secret, $data);

  /**
   * Decrypts data using the given secret.
   *
   * @param string $secret
   *   Secret key - no need to base64encode - will be encoded by the method.
   * @param string $data
   *   Decrypted data
   *
   * @return string
   *   Decrypted content.
   */
  public static function decrypt($secret, $data);

}
