<?php

/**
 * @file
 * Contains \Drupal\entity_pilot\ExistsPluginInterface.
 */

namespace Drupal\entity_pilot;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\views\Plugin\views\PluginInterface;

/**
 * Defines an interface for Exists plugins.
 */
interface ExistsPluginInterface extends PluginInterface {

  /**
   * Determine if an incoming entity already exists on the site.
   *
   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
   *   Entity manager service.
   * @param \Drupal\Core\Entity\EntityInterface $passenger
   *   Entity being checked.
   *
   * @return \Drupal\Core\Entity\EntityInterface|FALSE
   *   The existing entity if one exists, else FALSE.
   */
  public function exists(EntityManagerInterface $entity_manager, EntityInterface $passenger);

  /**
   * Allows plugin to apply modify incoming entities from existing one.
   *
   * @param \Drupal\Core\Entity\EntityInterface $incoming
   *   The entity imported from EntityPilot.
   * @param \Drupal\Core\Entity\EntityInterface $existing
   *   The existing entity that matches.
   */
  public function preApprove(EntityInterface $incoming, EntityInterface $existing);

}
