<?php

/**
 * @file
 * Contains \Drupal\entity_pilot\Tests\EntityPilotTestBase.
 */

namespace Drupal\entity_pilot\Tests;

use Drupal\Component\Utility\Unicode;
use Drupal\simpletest\WebTestBase;

/**
 * Provides a base test class for Entity Pilot tests.
 */
abstract class EntityPilotTestBase extends WebTestBase {

  /**
   * Profile to use.
   */
  protected $profile = 'testing';

  /**
   * Admin user
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * Permissions to grant admin user.
   *
   * @var array
   */
  protected $permissions = array(
    'administer entity_pilot accounts',
    'administer entity_pilot arrivals',
    'administer entity_pilot departures',
  );

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = array(
    'entity_reference',
    'dynamic_entity_reference',
    'entity_pilot',
    'block',
  );

  /**
   * Sets the test up.
   */
  protected function setUp() {
    parent::setUp();
    $this->adminUser = $this->drupalCreateUser($this->permissions);
    $this->drupalPlaceBlock('local_tasks_block', ['id' => 'tabs_block']);
    $this->drupalPlaceBlock('page_title_block');
    $this->drupalPlaceBlock('local_actions_block', ['id' => 'actions_block']);
  }

  /**
   * Creates an Entity Pilot account (bundle).
   *
   * @param string $label
   *   The account label.
   * @param string $carrier_id
   *   (optional) Account carrier ID.
   * @param string $black_box_key
   *   (optional) Account black box key.
   * @param string $description
   *   (optional) Account description.
   *
   * @return \Drupal\entity_pilot\AccountInterface
   *   Created Entity Pilot account.
   */
  protected function createAccount($label, $carrier_id = NULL, $black_box_key = NULL, $description = NULL) {
    $bundle = entity_create('ep_account', array(
      'id' => Unicode::strtolower($label),
      'label' => $label,
      'carrierId' => $carrier_id ?: $this->randomMachineName(),
      'blackBoxKey' => $black_box_key ?: $this->randomMachineName(),
      'description' => $description ?: $this->randomMachineName(),
        'secret' => "a22a0b2884fd73c4e211d68e1f031051",
    ));
    $bundle->save();
    return $bundle;
  }

  /**
   * Creates a departure flight.
   *
   * @param string|bool $info
   *   (optional) Brief name of flight. Defaults to FALSE.
   *   Defaults to FALSE.
   * @param string $bundle
   *   (optional) Bundle name. Defaults to 'primary'.
   *
   * @return \Drupal\entity_pilot\DepartureInterface
   *   Created flight.
   */
  protected function createDeparture($info = FALSE, $bundle = 'primary') {
    if ($flight = entity_create('ep_departure', array(
      'info' => $info ?: $this->randomMachineName(),
      'account' => $bundle,
      'langcode' => 'en',
    ))) {
      $flight->save();
    }
    return $flight;
  }

}
